@@ -5,26 +5,20 @@ This collects the general public API into a single spot for inclusion, as
 !*/
 
 pub use crate::{
-	access::BitAccess,
-	bits::{
-		Bits,
-		BitsMut,
-	},
-	cursor::{
-		Cursor,
-		BigEndian,
-		LittleEndian,
-		Local,
-	},
+	bits,
+	bits::Bits,
 	fields::BitField,
+	order::{
+		BitOrder,
+		Local,
+		Lsb0,
+		Msb0,
+	},
 	slice::{
 		BitMut,
 		BitSlice,
 	},
-	store::{
-		BitStore,
-		Word,
-	},
+	store::BitStore,
 };
 
 #[cfg(feature = "alloc")]
