@@ -10,24 +10,21 @@ Rust slices, and must never be interchanged except through the provided APIs.
 
 use crate::{
 	access::BitAccess,
-	cursor::{
-		Cursor,
-		Local,
-	},
 	domain::*,
 	indices::Indexable,
-	pointer::BitPtr,
-	store::{
-		BitStore,
-		Word,
+	order::{
+		BitOrder,
+		Local,
 	},
+	pointer::BitPtr,
+	store::BitStore,
 };
 
 use core::marker::PhantomData;
 
 use either::Either;
 
-/** A compact slice of bits, whose cursor and storage types can be customized.
+/** A compact slice of bits, whose order and storage types can be customized.
 
 `BitSlice` is a specialized slice type, which can only ever be held by
 reference or specialized owning pointers provided by this crate. The value
@@ -55,11 +52,11 @@ let bslice: &BitSlice = &bv[..];
 # }
 
 //  coercing an array to a bitslice
-let bslice: &BitSlice<_, _> = [1u8, 254u8].bits::<BigEndian>();
+let bslice: &BitSlice<_, _> = [1u8, 254u8].bits::<Msb0>();
 ```
 
 Bit slices are either mutable or shared. The shared slice type is
-`&BitSlice<C, T>`, while the mutable slice type is `&mut BitSlice<C, T>`. For
+`&BitSlice<O, T>`, while the mutable slice type is `&mut BitSlice<O, T>`. For
 example, you can mutate bits in the memory to which a mutable `BitSlice` points:
 
 ```rust
@@ -67,7 +64,7 @@ use bitvec::prelude::*;
 
 let mut base = [0u8, 0, 0, 0];
 {
- let bs: &mut BitSlice<_, _> = base.bits_mut::<BigEndian>();
+ let bs: &mut BitSlice<_, _> = base.bits_mut::<Msb0>();
  bs.set(13, true);
  eprintln!("{:?}", bs.as_ref());
  assert!(bs[13]);
@@ -77,7 +74,7 @@ assert_eq!(base[1], 4);
 
 # Type Parameters
 
-- `C`: An implementor of the `Cursor` trait. This type is used to convert
+- `O`: An implementor of the `BitOrder` trait. This type is used to convert
   semantic indices into concrete bit positions in elements, and store or
   retrieve bit values from the storage type.
 - `T`: An implementor of the `BitStore` trait: `u8`, `u16`, `u32`, or `u64`
@@ -98,10 +95,10 @@ is ***catastrophically*** unsafe and unsound.
 [`bitvec!`]: ../macro.bitvec.html
 **/
 #[repr(transparent)]
-pub struct BitSlice<C = Local, T = Word>
-where C: Cursor, T: BitStore {
-	/// Cursor type for selecting bits inside an element.
-	_kind: PhantomData<C>,
+pub struct BitSlice<O = Local, T = usize>
+where O: BitOrder, T: BitStore {
+	/// BitOrder type for selecting bits inside an element.
+	_kind: PhantomData<O>,
 	/// Element type of the slice.
 	///
 	/// eddyb recommends using `PhantomData<T>` and `[()]` instead of `[T]`
@@ -111,8 +108,8 @@ where C: Cursor, T: BitStore {
 	_elts: [()],
 }
 
-impl<C, T> BitSlice<C, T>
-where C: Cursor, T: BitStore {
+impl<O, T> BitSlice<O, T>
+where O: BitOrder, T: BitStore {
 	/// Produces the empty slice. This is equivalent to `&[]` for Rust slices.
 	///
 	/// # Returns
@@ -126,6 +123,7 @@ where C: Cursor, T: BitStore {
 	///
 	/// let bits: &BitSlice = BitSlice::empty();
 	/// ```
+	#[inline]
 	pub fn empty<'a>() -> &'a Self {
 		BitPtr::empty().into_bitslice()
 	}
@@ -144,6 +142,7 @@ where C: Cursor, T: BitStore {
 	///
 	/// let bits: &mut BitSlice = BitSlice::empty_mut();
 	/// ```
+	#[inline]
 	pub fn empty_mut<'a>() -> &'a mut Self {
 		BitPtr::empty().into_bitslice_mut()
 	}
@@ -168,6 +167,7 @@ where C: Cursor, T: BitStore {
 	/// let bs: &BitSlice<Local, _> = BitSlice::from_element(&elt);
 	/// assert!(bs.all());
 	/// ```
+	#[inline]
 	pub fn from_element(elt: &T) -> &Self {
 		unsafe {
 			BitPtr::new_unchecked(elt, 0u8.idx(), T::BITS as usize)
@@ -195,13 +195,14 @@ where C: Cursor, T: BitStore {
 	/// bs.set(0, false);
 	/// assert!(!bs.all());
 	/// ```
+	#[inline]
 	pub fn from_element_mut(elt: &mut T) -> &mut Self {
 		unsafe {
 			BitPtr::new_unchecked(elt, 0u8.idx(), T::BITS as usize)
 		}.into_bitslice_mut()
 	}
 
-	/// Wraps a `&[T: BitStore]` in a `&BitSlice<C: Cursor, T>`. The cursor must
+	/// Wraps a `&[T: BitStore]` in a `&BitSlice<O: BitOrder, T>`. The order must
 	/// be specified at the call site. The element type cannot be changed.
 	///
 	/// # Parameters
@@ -223,7 +224,7 @@ where C: Cursor, T: BitStore {
 	/// use bitvec::prelude::*;
 	///
 	/// let src = [1, 2, 3];
-	/// let bits = BitSlice::<BigEndian, u8>::from_slice(&src[..]);
+	/// let bits = BitSlice::<Msb0, u8>::from_slice(&src[..]);
 	/// assert_eq!(bits.len(), 24);
 	/// assert_eq!(bits.as_ref().len(), 3);
 	/// assert!(bits[7]);  // src[0] == 0b0000_0001
@@ -245,8 +246,8 @@ where C: Cursor, T: BitStore {
 		BitPtr::new(slice.as_ptr(), 0u8.idx(), bits).into_bitslice()
 	}
 
-	/// Wraps a `&mut [T: BitStore]` in a `&mut BitSlice<C: Cursor, T>`. The
-	/// cursor must be specified by the call site. The element type cannot
+	/// Wraps a `&mut [T: BitStore]` in a `&mut BitSlice<O: BitOrder, T>`. The
+	/// order must be specified by the call site. The element type cannot
 	/// be changed.
 	///
 	/// # Parameters
@@ -268,7 +269,7 @@ where C: Cursor, T: BitStore {
 	/// use bitvec::prelude::*;
 	///
 	/// let mut src = [1, 2, 3];
-	/// let bits = BitSlice::<LittleEndian, u8>::from_slice_mut(&mut src[..]);
+	/// let bits = BitSlice::<Lsb0, u8>::from_slice_mut(&mut src[..]);
 	/// //  The first bit is the LSb of the first element.
 	/// assert!(bits[0]);
 	/// bits.set(0, false);
@@ -277,6 +278,7 @@ where C: Cursor, T: BitStore {
 	/// ```
 	///
 	/// [`BitPtr`]: ../pointer/struct.BitPtr.html
+	#[inline]
 	pub fn from_slice_mut(slice: &mut [T]) -> &mut Self {
 		Self::from_slice(slice).bitptr().into_bitslice_mut()
 	}
@@ -300,7 +302,7 @@ where C: Cursor, T: BitStore {
 	/// use bitvec::prelude::*;
 	///
 	/// let mut store = 8u8;
-	/// let bits = store.bits_mut::<BigEndian>();
+	/// let bits = store.bits_mut::<Msb0>();
 	/// assert!(!bits[3]);
 	/// bits.set(3, true);
 	/// assert!(bits[3]);
@@ -347,7 +349,7 @@ where C: Cursor, T: BitStore {
 	///
 	/// let mut src = 0u8;
 	/// {
-	///  let bits = &mut src.bits_mut::<BigEndian>()[2 .. 4];
+	///  let bits = &mut src.bits_mut::<Msb0>()[2 .. 4];
 	///  assert_eq!(bits.len(), 2);
 	///  unsafe { bits.set_unchecked(5, true); }
 	/// }
@@ -359,43 +361,41 @@ where C: Cursor, T: BitStore {
 		let bitptr = self.bitptr();
 		let (elt, bit) = bitptr.head().offset(index as isize);
 		let data_ptr = bitptr.pointer().a();
-		(&*data_ptr.offset(elt)).set::<C>(bit, value);
+		(*data_ptr.offset(elt)).set::<O>(bit, value);
 	}
 
-	/// Produces a write reference to a single bit in the slice.
+	/// Produces a write reference to a region of the slice.
 	///
-	/// The structure returned by this method extends the borrow until it drops,
-	/// which precludes parallel use.
+	/// This method corresponds to [`Index::index`], except that it produces a
+	/// writable reference rather than a read-only reference. See
+	/// [`BitSliceIndex`] for the possible types of the produced reference.
 	///
-	/// The [`split_at_mut`] method allows splitting the borrows of a slice, and
-	/// will enable safe parallel use of these write references. The `atomic`
-	/// feature guarantees that parallel use does not cause data races when
-	/// modifying the underlying slice.
+	/// Use of this method locks the `&mut BitSlice` for the duration of the
+	/// produced reference’s lifetime. If you need multiple **non-overlapping**
+	/// write references into a single source `&mut BitSlice`, see the
+	/// [`::split_at_mut`] method.
 	///
 	/// # Lifetimes
 	///
-	/// - `'a` Propagates the lifetime of the referent slice to the single-bit
+	/// - `'a`: Propagates the lifetime of the referent slice to the interior
 	///   reference produced.
 	///
 	/// # Parameters
 	///
 	/// - `&mut self`
-	/// - `index`: The index of the bit in `self` selected.
+	/// - `index`: Some value whose type can be used to index `BitSlice`s.
 	///
 	/// # Returns
 	///
-	/// A write reference to the requested bit. Due to Rust limitations, this is
-	/// not a native reference type, but is a custom structure that holds the
-	/// address of the requested bit and its value. The produced structure
-	/// implements `Deref` and `DerefMut` to its cached bit, and commits the
-	/// cached bit to the parent slice on drop.
+	/// A writable reference into `self`, whose exact type is determined by
+	/// `index`’s implementation of [`BitSliceIndex`]. This may be either a
+	/// smaller `&mut BitSlice` when `index` is a range, or a [`BitMut`] proxy
+	/// type when `index` is a `usize`. See the [`BitMut`] documentation for
+	/// information on how to use it.
 	///
-	/// # Usage
+	/// # Panics
 	///
-	/// You must use the dereference operator on the `.at()` expression in order
-	/// to assign to it. In general, you should prefer immediately using and
-	/// discarding the returned value, rather than binding it to a name and
-	/// letting it live for more than one statement.
+	/// This panics if `index` is out of bounds of `self`.
 	///
 	/// # Examples
 	///
@@ -403,7 +403,7 @@ where C: Cursor, T: BitStore {
 	/// use bitvec::prelude::*;
 	///
 	/// let mut src = 0u8;
-	/// let bits = src.bits_mut::<BigEndian>();
+	/// let bits = src.bits_mut::<Msb0>();
 	///
 	/// assert!(!bits[0]);
 	/// *bits.at(0) = true;
@@ -417,7 +417,7 @@ where C: Cursor, T: BitStore {
 	/// use bitvec::prelude::*;
 	///
 	/// let mut src = 0u8;
-	/// let bits = src.bits_mut::<BigEndian>();
+	/// let bits = src.bits_mut::<Msb0>();
 	///
 	/// {
 	///  let (mut a, rest) = bits.split_at_mut(2);
@@ -434,11 +434,13 @@ where C: Cursor, T: BitStore {
 	/// The above example splits the slice into three (the first, the second,
 	/// and the rest) in order to hold multiple write references into the slice.
 	///
-	/// [`split_at_mut`]: #method.split_at_mut
-	pub fn at(&mut self, index: usize) -> BitMut<C, T> {
-		let len = self.len();
-		assert!(index < len, "Index {} out of bounds: {}", index, len);
-		unsafe { self.at_unchecked(index) }
+	/// [`BitSliceIndex`]: trait.BitSliceIndex.html
+	/// [`::get`]: #method.get
+	/// [`::split_at_mut`]: #method.split_at_mut
+	#[inline]
+	pub fn at<'a, I>(&'a mut self, index: I) -> I::Mut
+	where I: BitSliceIndex<'a, O, T> {
+		index.index_mut(self)
 	}
 
 	/// Version of [`at`](#method.at) that does not perform boundary checking.
@@ -448,11 +450,10 @@ where C: Cursor, T: BitStore {
 	/// If `index` is outside the boundaries of `self`, then this function will
 	/// induce safety violations. The caller must ensure that `index` is within
 	/// the boundaries of `self` before calling.
-	pub unsafe fn at_unchecked(&mut self, index: usize) -> BitMut<C, T> {
-		BitMut {
-			data: *self.get_unchecked(index),
-			slot: self.get_unchecked_mut(index ..= index),
-		}
+	#[inline]
+	pub unsafe fn at_unchecked<'a, I>(&'a mut self, index: I) -> I::Mut
+	where I: BitSliceIndex<'a, O, T> {
+		index.get_unchecked_mut(self)
 	}
 
 	/// Version of [`split_at`](#method.split_at) that does not perform boundary
@@ -479,6 +480,7 @@ where C: Cursor, T: BitStore {
 	/// If `mid` is outside the boundaries of `self`, then this function will
 	/// induce safety violations. The caller must ensure that `mid` is within
 	/// the boundaries of `self` before calling.
+	#[inline]
 	pub unsafe fn split_at_mut_unchecked(
 		&mut self,
 		mid: usize,
@@ -487,6 +489,20 @@ where C: Cursor, T: BitStore {
 		(head.bitptr().into_bitslice_mut(), tail.bitptr().into_bitslice_mut())
 	}
 
+	/// Version of [`swap`](#method.swap) that does not perform boundary checks.
+	///
+	/// # Safety
+	///
+	/// `a` and `b` must be within the bounds of `self`, otherwise, the memory
+	/// access is unsound and may induce undefined behavior.
+	#[inline]
+	pub unsafe fn swap_unchecked(&mut self, a: usize, b: usize) {
+		let bit_a = *self.get_unchecked(a);
+		let bit_b = *self.get_unchecked(b);
+		self.set_unchecked(a, bit_b);
+		self.set_unchecked(b, bit_a);
+	}
+
 	/// Tests if *all* bits in the slice domain are set (logical `∧`).
 	///
 	/// # Truth Table
@@ -512,7 +528,7 @@ where C: Cursor, T: BitStore {
 	/// ```rust
 	/// use bitvec::prelude::*;
 	///
-	/// let bits = 0xFDu8.bits::<BigEndian>();
+	/// let bits = 0xFDu8.bits::<Msb0>();
 	/// assert!(bits[.. 4].all());
 	/// assert!(!bits[4 ..].all());
 	/// ```
@@ -520,22 +536,27 @@ where C: Cursor, T: BitStore {
 		match self.bitptr().domain().splat() {
 			Either::Right((h, e, t)) => {
 				let elt = e.load();
-				(*h .. *t).all(|n| elt.get::<C>(n.idx()))
+				(*h .. *t).all(|n| elt.get::<O>(n.idx()))
 			},
 			Either::Left((h, b, t)) => {
-				let mut out = true;
 				if let Some((h, head)) = h {
 					let elt = head.load();
-					out &= (*h .. T::BITS).all(|n| elt.get::<C>(n.idx()));
+					if !(*h .. T::BITS).all(|n| elt.get::<O>(n.idx())) {
+						return false;
+					}
 				}
 				if let Some(body) = b {
-					out &= body.iter().all(|e| e.load() == T::TRUE);
+					if !body.iter().all(|e| e.load() == T::TRUE) {
+						return false;
+					}
 				}
 				if let Some((tail, t)) = t {
 					let elt = tail.load();
-					out &= (0 .. *t).all(|n| elt.get::<C>(n.idx()));
+					if !(0 .. *t).all(|n| elt.get::<O>(n.idx())) {
+						return false;
+					}
 				}
-				out
+				true
 			},
 		}
 	}
@@ -565,7 +586,7 @@ where C: Cursor, T: BitStore {
 	/// ```rust
 	/// use bitvec::prelude::*;
 	///
-	/// let bits = 0x40u8.bits::<BigEndian>();
+	/// let bits = 0x40u8.bits::<Msb0>();
 	/// assert!(bits[.. 4].any());
 	/// assert!(!bits[4 ..].any());
 	/// ```
@@ -573,22 +594,27 @@ where C: Cursor, T: BitStore {
 		match self.bitptr().domain().splat() {
 			Either::Right((h, e, t)) => {
 				let elt = e.load();
-				(*h .. *t).any(|n| elt.get::<C>(n.idx()))
+				(*h .. *t).any(|n| elt.get::<O>(n.idx()))
 			},
 			Either::Left((h, b, t)) => {
-				let mut out = false;
 				if let Some((h, head)) = h {
 					let elt = head.load();
-					out |= (*h .. T::BITS).any(|n| elt.get::<C>(n.idx()));
+					if (*h .. T::BITS).any(|n| elt.get::<O>(n.idx())) {
+						return true;
+					}
 				}
 				if let Some(body) = b {
-					out |= body.iter().any(|elt| elt.load() != T::FALSE);
+					if body.iter().any(|elt| elt.load() != T::FALSE) {
+						return true;
+					}
 				}
 				if let Some((tail, t)) = t {
 					let elt = tail.load();
-					out |= (0 .. *t).any(|n| elt.get::<C>(n.idx()));
+					if (0 .. *t).any(|n| elt.get::<O>(n.idx())) {
+						return true;
+					}
 				}
-				out
+				false
 			},
 		}
 	}
@@ -617,10 +643,11 @@ where C: Cursor, T: BitStore {
 	/// ```rust
 	/// use bitvec::prelude::*;
 	///
-	/// let bits = 0xFDu8.bits::<BigEndian>();
+	/// let bits = 0xFDu8.bits::<Msb0>();
 	/// assert!(!bits[.. 4].not_all());
 	/// assert!(bits[4 ..].not_all());
 	/// ```
+	#[inline]
 	pub fn not_all(&self) -> bool {
 		!self.all()
 	}
@@ -649,10 +676,11 @@ where C: Cursor, T: BitStore {
 	/// ```rust
 	/// use bitvec::prelude::*;
 	///
-	/// let bits = 0x40u8.bits::<BigEndian>();
+	/// let bits = 0x40u8.bits::<Msb0>();
 	/// assert!(!bits[.. 4].not_any());
 	/// assert!(bits[4 ..].not_any());
 	/// ```
+	#[inline]
 	pub fn not_any(&self) -> bool {
 		!self.any()
 	}
@@ -685,11 +713,12 @@ where C: Cursor, T: BitStore {
 	/// ```rust
 	/// use bitvec::prelude::*;
 	///
-	/// let bits = 0b111_000_10u8.bits::<BigEndian>();
+	/// let bits = 0b111_000_10u8.bits::<Msb0>();
 	/// assert!(!bits[0 .. 3].some());
 	/// assert!(!bits[3 .. 6].some());
 	/// assert!(bits[6 ..].some());
 	/// ```
+	#[inline]
 	pub fn some(&self) -> bool {
 		self.any() && self.not_all()
 	}
@@ -709,21 +738,21 @@ where C: Cursor, T: BitStore {
 	/// ```rust
 	/// use bitvec::prelude::*;
 	///
-	/// let bits = [0xFDu8, 0x25].bits::<BigEndian>();
+	/// let bits = [0xFDu8, 0x25].bits::<Msb0>();
 	/// assert_eq!(bits.count_ones(), 10);
 	/// ```
 	pub fn count_ones(&self) -> usize {
 		match self.bitptr().domain().splat() {
 			Either::Right((h, e, t)) => {
 				let elt = e.load();
-				(*h .. *t).filter(|n| elt.get::<C>(n.idx())).count()
+				(*h .. *t).filter(|n| elt.get::<O>(n.idx())).count()
 			},
 			Either::Left((h, b, t)) => {
 				let mut out = 0usize;
 				if let Some((h, head)) = h {
 					let elt = head.load();
 					out += (*h .. T::BITS)
-						.filter(|n| elt.get::<C>(n.idx()))
+						.filter(|n| elt.get::<O>(n.idx()))
 						.count();
 				}
 				if let Some(body) = b {
@@ -735,7 +764,7 @@ where C: Cursor, T: BitStore {
 				if let Some((tail, t)) = t {
 					let elt = tail.load();
 					out += (0 .. *t)
-						.filter(|n| elt.get::<C>(n.idx()))
+						.filter(|n| elt.get::<O>(n.idx()))
 						.count();
 				}
 				out
@@ -758,7 +787,7 @@ where C: Cursor, T: BitStore {
 	/// ```rust
 	/// use bitvec::prelude::*;
 	///
-	/// let bits = [0xFDu8, 0x25].bits::<BigEndian>();
+	/// let bits = [0xFDu8, 0x25].bits::<Msb0>();
 	/// assert_eq!(bits.count_zeros(), 6);
 	/// ```
 	pub fn count_zeros(&self) -> usize {
@@ -778,7 +807,7 @@ where C: Cursor, T: BitStore {
 	/// use bitvec::prelude::*;
 	///
 	/// let mut src = 0u8;
-	/// let bits = src.bits_mut::<BigEndian>();
+	/// let bits = src.bits_mut::<Msb0>();
 	/// bits[2 .. 6].set_all(true);
 	/// assert_eq!(bits.as_ref(), &[0b0011_1100]);
 	/// bits[3 .. 5].set_all(false);
@@ -790,13 +819,13 @@ where C: Cursor, T: BitStore {
 		match self.bitptr().domain().splat() {
 			Either::Right((h, e, t)) => {
 				for n in *h .. *t {
-					e.set::<C>(n.idx(), value);
+					e.set::<O>(n.idx(), value);
 				}
 			},
 			Either::Left((h, b, t)) => {
 				if let Some((h, head)) = h {
 					for n in *h .. T::BITS {
-						head.set::<C>(n.idx(), value);
+						head.set::<O>(n.idx(), value);
 					}
 				}
 				if let Some(body) = b {
@@ -806,7 +835,7 @@ where C: Cursor, T: BitStore {
 				}
 				if let Some((tail, t)) = t {
 					for n in 0 .. *t {
-						tail.set::<C>(n.idx(), value);
+						tail.set::<O>(n.idx(), value);
 					}
 				}
 			},
@@ -834,7 +863,7 @@ where C: Cursor, T: BitStore {
 	///
 	/// let mut src = 0u8;
 	/// {
-	///  let bits = src.bits_mut::<BigEndian>();
+	///  let bits = src.bits_mut::<Msb0>();
 	///  bits.for_each(|idx, _bit| idx % 3 == 0);
 	/// }
 	/// assert_eq!(src, 0b1001_0010);
@@ -842,9 +871,11 @@ where C: Cursor, T: BitStore {
 	pub fn for_each<F>(&mut self, func: F)
 	where F: Fn(usize, bool) -> bool {
 		for idx in 0 .. self.len() {
-			let tmp = unsafe { *self.get_unchecked(idx) };
-			let new = func(idx, tmp);
-			unsafe { self.set_unchecked(idx, new); }
+			unsafe {
+				let tmp = *self.get_unchecked(idx);
+				let new = func(idx, tmp);
+				self.set_unchecked(idx, new);
+			}
 		}
 	}
 
@@ -853,7 +884,7 @@ where C: Cursor, T: BitStore {
 	/// This addition interprets the slice, and the other addend, as having its
 	/// least significant bits first in the order and its most significant bits
 	/// last. This is most likely to be numerically useful under a
-	/// `LittleEndian` `Cursor` type.
+	/// `Lsb0` `BitOrder` type.
 	///
 	/// # Parameters
 	///
@@ -887,8 +918,8 @@ where C: Cursor, T: BitStore {
 	/// let mut a = 0b0000_1010u8;
 	/// let     b = 0b0000_1100u8;
 	/// //      s =      1 0110
-	/// let ab = &mut a.bits_mut::<LittleEndian>()[.. 4];
-	/// let bb = &    b.bits::<LittleEndian>()[.. 4];
+	/// let ab = &mut a.bits_mut::<Lsb0>()[.. 4];
+	/// let bb = &    b.bits::<Lsb0>()[.. 4];
 	/// let c = ab.add_assign_reverse(bb.iter().copied());
 	/// assert!(c);
 	/// assert_eq!(a, 0b0000_0110u8);
@@ -896,14 +927,14 @@ where C: Cursor, T: BitStore {
 	///
 	/// # Performance Notes
 	///
-	/// When using `LittleEndian` `Cursor` types, this can be accelerated by
+	/// When using `Lsb0` `BitOrder` types, this can be accelerated by
 	/// delegating the addition to the underlying types. This is a software
 	/// implementation of the [ripple-carry adder], which has `O(n)` runtime in
 	/// the number of bits. The CPU is much faster, as it has access to
 	/// element-wise or vectorized addition operations.
 	///
 	/// If your use case sincerely needs binary-integer arithmetic operations on
-	/// bit sets
+	/// bit sets, please file an issue.
 	///
 	/// [ripple-carry adder]: https://en.wikipedia.org/wiki/Ripple-carry_adder
 	pub fn add_assign_reverse<I>(&mut self, addend: I) -> bool
@@ -914,12 +945,14 @@ where C: Cursor, T: BitStore {
 		let zero = core::iter::repeat(false);
 		for (i, b) in addend.into_iter().chain(zero).enumerate().take(len) {
 			//  The iterator is clamped to the upper bound of `self`.
-			let a = unsafe { *self.get_unchecked(i) };
-			let (y, z) = crate::rca1(a, b, c);
-			//  Write the sum into `self`
-			unsafe { self.set_unchecked(i, y); }
-			//  Propagate the carry
-			c = z;
+			c = unsafe {
+				let a = *self.get_unchecked(i);
+				let (y, z) = crate::rca1(a, b, c);
+				//  Write the sum into `self`
+				self.set_unchecked(i, y);
+				//  Propagate the carry
+				z
+			};
 		}
 		c
 	}
@@ -944,7 +977,7 @@ where C: Cursor, T: BitStore {
 	/// use bitvec::prelude::*;
 	///
 	/// let src = [1u8, 66];
-	/// let bits = src.bits::<BigEndian>();
+	/// let bits = src.bits::<Msb0>();
 	///
 	/// let accum = bits.as_slice()
 	///   .iter()
@@ -974,7 +1007,7 @@ where C: Cursor, T: BitStore {
 	/// use bitvec::prelude::*;
 	///
 	/// let mut src = [1u8, 64];
-	/// let bits = src.bits_mut::<BigEndian>();
+	/// let bits = src.bits_mut::<Msb0>();
 	/// for elt in bits.as_mut_slice() {
 	///   *elt |= 2;
 	/// }
@@ -1004,6 +1037,7 @@ where C: Cursor, T: BitStore {
 	///
 	/// A slice of all elements under the bit span, including any
 	/// partially-owned edge elements, wrapped in safe shared-mutation types.
+	#[inline]
 	pub fn as_total_slice(&self) -> &[T::Access] {
 		self.bitptr().as_access_slice()
 	}
@@ -1019,6 +1053,7 @@ where C: Cursor, T: BitStore {
 	/// The [`BitPtr`] structure of the slice handle.
 	///
 	/// [`BitPtr`]: ../pointer/struct.BitPtr.html
+	#[inline]
 	pub(crate) fn bitptr(&self) -> BitPtr<T> {
 		BitPtr::from_bitslice(self)
 	}
@@ -1035,22 +1070,23 @@ where C: Cursor, T: BitStore {
 	///
 	/// `from` and `to` must be within the bounds of `self`. This is not
 	/// checked.
-	unsafe fn copy_unchecked(&mut self, from: usize, to: usize) {
+	#[inline]
+	pub(crate) unsafe fn copy_unchecked(&mut self, from: usize, to: usize) {
 		self.set_unchecked(to, *self.get_unchecked(from));
 	}
 }
 
 mod api;
-mod guard;
 pub(crate) mod iter;
 mod ops;
+mod proxy;
 mod traits;
 
 //  Match the `core::slice` API module topology.
 
 pub use self::api::*;
-pub use self::guard::*;
 pub use self::iter::*;
+pub use self::proxy::*;
 
 #[cfg(test)]
 mod tests;
